/*
 * Account.java
 *
 * Created on December 13, 2001, 9:17 AM
 */

package com.systinet.demos.bank;

/**
 * Account interface
 */
public interface Account
    extends java.rmi.Remote
{

    /**
     * Returns the account number
     * @return account number
     * @throws AuthenticationException if authentication fails
     */
    public String getAccountNumber() throws AuthenticationException;

    /**
     * Sets the account number
     * @param accountNumber account number
     * @throws AuthenticationException if authentication fails
     */
    public void setAccountNumber(String accountNumber) throws AuthenticationException;

    /**
     *  Returns the account balance
     * @return the actual balance of the account
     * @throws AuthenticationException if authentication fails
     */
    public double getBalance() throws AuthenticationException;

    /**
     *  Sets the account balance
     * @param amount the actual balance of the account
     * @throws AuthenticationException if authentication fails
     */
    public void setBalance(double amount) throws AuthenticationException;

    /**
     * Deposits to the account
     * @param amount amount of many to deposit
     * @throws AuthenticationException if authentication fails
     */
    public void deposit(double amount) throws AuthenticationException;

    /**
     * Withdraw from the account
     * @param amount amount to withdraw
     * @throws UnsufficientFundsException thrown if account doesn't hava enough funds
     * @throws AuthenticationException if authentication fails
     */
    public void withdraw(double amount)
        throws UnsufficientFundsException, AuthenticationException;

    /**
     * Close the account
     * @throws AuthenticationException if authentication fails
     */
    public void close() throws AuthenticationException;

}
